@@ -519,7 +519,7 @@ do_shutdown_action (UsdMediaKeysManager *manager)
 static void
 do_logout_action (UsdMediaKeysManager *manager)
 {
-        execute (manager, "ukui-session-save --logout-dialog", FALSE, FALSE);
+        execute (manager, "gnome-system-monitor", FALSE, FALSE);
 }
 
 static void
@@ -1004,6 +1004,13 @@ do_action (UsdMediaKeysManager *manager,
 
                 g_free (cmd);
                 break;
+        case SETTINGS_KEY:
+                execute(manager, "ukui-control-center", FALSE, FALSE);
+                break;
+        case FILE_MANAGER_KEY:
+                //execute(manager, "peony", FALSE, FALSE);
+		system("peony");
+                break;
         case HELP_KEY:
                 do_url_action (manager, "help");
                 break;
